@@ -3,7 +3,7 @@
 ** Purpose:     wxWidgets wrapper around the SQLite3 embedded database library.
 ** Author:      Ulrich Telle
 ** Created:     2005-07-14
-** Copyright:   (c) 2005-2023 Ulrich Telle
+** Copyright:   (c) 2005-2025 Ulrich Telle
 ** License:     LGPL-3.0+ WITH WxWindows-exception-3.1
 */
 
@@ -46,6 +46,112 @@
 
 <dl>
 
+<dt><b>4.10.7</b> - <i>June 2025</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 2.1.2 (SQLite version 3.50.0)</i><br>
+Add method wxSQLite3Database::SetLockTimeout()
+
+</dd>
+
+<dt><b>4.10.6</b> - <i>May 2025</i></dt>
+<dd>
+Add method wxSQLite3Database::Configure()<br>
+Add missing wxSQLite3Database::Restore() method variant<br>
+Fix mapping between cipher ids and cipher names
+
+</dd>
+
+<dt><b>4.10.5</b> - <i>March 2025</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 2.1.0 (SQLite version 3.49.1)</i><br>
+Disable AEGIS cipher scheme when compiling with MSVC 2015 or below
+
+</dd>
+
+<dt><b>4.10.4</b> - <i>February 2025</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 2.0.4 (SQLite version 3.49.1)</i>
+
+</dd>
+
+<dt><b>4.10.3</b> - <i>February 2025</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 2.0.3 (SQLite version 3.49.0)</i>
+
+</dd>
+
+<dt><b>4.10.2</b> - <i>January 2025</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 2.0.2 (SQLite version 3.48.0)</i>
+
+</dd>
+
+<dt><b>4.10.1</b> - <i>January 2025</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 2.0.1 (SQLite version 3.47.2)</i><br>
+Fixed issue #120 - crashes on some Linux systems due to <i>illegal instruction</i> exceptions related to the code of the new cipher scheme <i>AEGIS</i>
+
+</dd>
+
+<dt><b>4.10.0</b> - <i>December 2024</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 2.0.0 (SQLite version 3.47.2)</i><br>
+Removed <i>User Authentication</i> extension<br>
+Added new cipher scheme AEGIS
+
+</dd>
+
+<dt><b>4.9.12</b> - <i>October 2024</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.9.0 (SQLite version 3.47.0)</i>
+
+</dd>
+
+<dt><b>4.9.11</b> - <i>June 2024</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.6 (SQLite version 3.46.0)</i>
+
+</dd>
+
+<dt><b>4.9.10</b> - <i>March 2024</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.4 (SQLite version 3.45.2)</i><br>
+Disable user authentication extension in build files by default
+
+</dd>
+
+<dt><b>4.9.9</b> - <i>January 2024</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.2 (SQLite version 3.45.0)</i>
+
+</dd>
+
+<dt><b>4.9.8</b> - <i>November 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.0 (SQLite version 3.44.1)</i><br>
+Added new cipher scheme Ascon-128 (Lightweight Authenticated Encryption)
+
+</dd>
+
+<dt><b>4.9.7</b> - <i>November 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.7.4 (SQLite version 3.44.0)</i><br>
+Prevent crashes due to uninitialized cipher tables (issue #113)
+
+</dd>
+
+<dt><b>4.9.6</b> - <i>October 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.7.0 (SQLite version 3.43.1)</i><br>
+
+</dd>
+
+<dt><b>4.9.5</b> - <i>September 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.5 (SQLite version 3.43.1)</i><br>
+
+</dd>
+
 <dt><b>4.9.4</b> - <i>May 2023</i></dt>
 <dd>
 Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.3 (SQLite version 3.42.0)</i><br>
